@@ -6,7 +6,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-// UNSUPPORTED: c++03
+// REQUIRES: can-create-symlinks
+// UNSUPPORTED: c++03, c++11, c++14
 // UNSUPPORTED: no-filesystem
 // UNSUPPORTED: availability-filesystem-missing
 
@@ -16,20 +17,20 @@
 
 // directory_iterator& operator=(directory_iterator const&);
 
-#include "filesystem_include.h"
+#include <filesystem>
 #include <type_traits>
 #include <set>
 #include <cassert>
 
 #include "test_macros.h"
 #include "filesystem_test_helper.h"
+namespace fs = std::filesystem;
+using namespace fs;
 
 // The filesystem specification explicitly allows for self-move on
 // the directory iterators. Turn off this warning so we can test it.
 TEST_CLANG_DIAGNOSTIC_IGNORED("-Wself-move")
 
-using namespace fs;
-
 static void test_assignment_signature()
 {
     using D = directory_iterator;
